@@ -102,6 +102,7 @@ _OTEL_EXPORTER_OTLP_TRACES_INSECURE = _env.bool(
 _OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE = _env.str(
     "OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE", "CUMULATIVE"
 )
+_OTEL_METRIC_EXPORT_INTERVAL = _env.int("OTEL_METRIC_EXPORT_INTERVAL", 60000)
 
 # FIXME Find a way to "import" this value from:
 # https://github.com/open-telemetry/opentelemetry-collector/blob/master/translator/conventions/opentelemetry.go
@@ -139,9 +140,10 @@ def configure_opentelemetry(
     metrics_enabled: bool = _LS_METRICS_ENABLED,
     span_exporter_endpoint: str = _OTEL_EXPORTER_OTLP_TRACES_ENDPOINT,
     metrics_exporter_endpoint: str = _OTEL_EXPORTER_OTLP_METRICS_ENDPOINT,
-    metrics_exporter_temporality_preference: str = (
+    metrics_exporter_temporality_preference: int = (
         _OTEL_EXPORTER_OTLP_METRICS_TEMPORALITY_PREFERENCE
     ),
+    metrics_exporter_interval: str = (_OTEL_METRIC_EXPORT_INTERVAL),
     service_name: str = _OTEL_SERVICE_NAME,
     service_version: str = _LS_SERVICE_VERSION,
     propagators: str = _OTEL_PROPAGATORS,
@@ -197,6 +199,8 @@ def configure_opentelemetry(
             `ObservableCounter`: `DELTA`
             `ObservableUpDownCounter`: `CUMULATIVE`
             `ObservableGauge`: `CUMULATIVE`
+        metrics_exporter_interval (int): OTEL_METRIC_EXPORT_INTERVAL, the
+            periodic interval in miliseconds to wait before exporting metrics.
         service_name (str): OTEL_SERVICE_NAME, the name of the service that is
             used along with the access token to send spans to the Lighstep
             satellite. This configuration value is mandatory.
@@ -249,7 +253,6 @@ def configure_opentelemetry(
     log_level = log_level.upper()
 
     if log_level not in log_levels:
-
         message = (
             f"Invalid configuration: invalid log_level value. "
             f"It must be one of {', '.join(log_levels.keys())}"
@@ -264,7 +267,6 @@ def configure_opentelemetry(
     _logger.debug("configuration")
 
     if not _validate_service_name(service_name):
-
         message = (
             "Invalid configuration: service name missing. "
             "Set environment variable OTEL_SERVICE_NAME"
@@ -312,7 +314,6 @@ def configure_opentelemetry(
     propagator_instances = []
 
     for propagator in propagators:
-
         try:
             propagator_instance = next(
                 iter_entry_points("opentelemetry_propagator", name=propagator),
@@ -355,7 +356,6 @@ def configure_opentelemetry(
     if _ATTRIBUTE_HOST_NAME not in resource_attributes.keys() or not (
         resource_attributes[_ATTRIBUTE_HOST_NAME]
     ):
-
         no_hostname_message = (
             "set it with the environment variable OTEL_RESOURCE_ATTRIBUTES or "
             'with the resource_attributes argument. Use "host.name" as key '
@@ -376,7 +376,6 @@ def configure_opentelemetry(
     tracer_provider = get_tracer_provider()
 
     if isinstance(tracer_provider, TracerProvider):
-
         # FIXME: Accessing a private attribute here because resource is no
         # longer settable since:
         # https://github.com/open-telemetry/opentelemetry-python/pull/1652
@@ -429,7 +428,6 @@ def configure_opentelemetry(
         )
 
     if metrics_enabled:
-
         _logger.debug("configuring metrics")
 
         logged_attributes[
@@ -437,7 +435,6 @@ def configure_opentelemetry(
         ] = metrics_exporter_endpoint
 
         if metrics_exporter_temporality_preference == "DELTA":
-
             instrument_class_temporality = {
                 Counter: AggregationTemporality.DELTA,
                 UpDownCounter: AggregationTemporality.CUMULATIVE,
@@ -448,7 +445,6 @@ def configure_opentelemetry(
             }
 
         elif metrics_exporter_temporality_preference == "CUMULATIVE":
-
             instrument_class_temporality = {
                 Counter: AggregationTemporality.CUMULATIVE,
                 UpDownCounter: AggregationTemporality.CUMULATIVE,
@@ -459,7 +455,6 @@ def configure_opentelemetry(
             }
 
         else:
-
             message = (
                 f"Invalid configuration: "
                 f"invalid metrics_exporter_temporality_preference: "
@@ -476,7 +471,9 @@ def configure_opentelemetry(
             preferred_temporality=instrument_class_temporality,
         )
 
-        reader = PeriodicExportingMetricReader(exporter)
+        reader = PeriodicExportingMetricReader(
+            exporter, export_timeout_millis=metrics_exporter_interval
+        )
 
         provider = MeterProvider(metric_readers=[reader])
 
